@@ -30,7 +30,9 @@ def performAnalysis(
     
     results = {}
     
-    results['paths'] = {}
+    results['landmarks'] = {}
+    
+    linePaths = {}
 
     side = params['side']
     
@@ -48,6 +50,15 @@ def performAnalysis(
     
     t = np.arange(N)
     
+    globalPoints = {}
+    
+    for m in params['mkrsLoc']:
+        if params['mkrsLoc'][m]['fixedTo'] == 'global':
+            pos = np.array(params['mkrsLoc'][m]['pos'])
+            globalPoints[m] = np.tile(pos[np.newaxis,:], (N, 1))
+        
+    results['landmarks'].update(globalPoints)
+    
     args = {}
     args['mkrsLoc'] = mkrsLoc
     args['verbose'] = False
@@ -61,6 +72,16 @@ def performAnalysis(
     segList = params['calcSegPoses']['selected']
 
     poses = {}
+    
+    axesLength = 100.
+    axesPoints = {
+        'O': np.array([0.,0.,0.]),
+        'X': np.array([axesLength,0.,0.]),
+        'Y': np.array([0.,axesLength,0.]),
+        'Z': np.array([0.,0.,axesLength]),
+    }
+
+    axes = {}
 
     for segName in segList:
 
@@ -106,9 +127,19 @@ def performAnalysis(
             pose['err_max_marker'] = [''] * N
             poses[segName] = pose
             
+        if type == 'define_from_markers':
+            axesPointsGlob = kine.changeMarkersReferenceFrame(axesPoints, RT)
+            for a in ['X', 'Y', 'Z']:
+                axesName = segName + '_' + a
+                axes[axesName] = [[]] * N
+                for i in range(N):
+                    axes[axesName][i] = np.array([axesPointsGlob['O'][i,:], axesPointsGlob[a][i,:]])
+            
     results['poses'] = poses
         
-    results['landmarks'] = {m: allALs[m] for m in allALs}
+    results['landmarks'].update({m: allALs[m] for m in allALs})
+    
+    linePaths.update(axes)
     
     defJoints = params['defJoints']
     
@@ -203,13 +234,21 @@ def performAnalysis(
 
         segIns1 = mkrsSegs[ins1]
         segIns2 = mkrsSegs[ins2]
+        segSpline = None
         if spline != '':
             segSpline = splinesSegs[spline]
 
-        RT1 = RTs[segIns1]
-        RT2 = RTs[segIns2]
+        if segIns1 == 'global':
+            RT1 = np.tile(np.eye(4)[np.newaxis,:,:], (N, 1, 1))
+        else:
+            RT1 = RTs[segIns1]
+        if segIns2 == 'global':
+            RT2 = np.tile(np.eye(4)[np.newaxis,:,:], (N, 1, 1))
+        else:
+            RT2 = RTs[segIns2]
+            
         if segSpline is not None:
-            RTs = RTs[segSpline]
+            RTe = RTs[segSpline]
 
         p1Loc = {ins1: mkrsLoc[ins1]}
         p1 = kine.changeMarkersReferenceFrame(p1Loc, RT1)[ins1]
@@ -233,7 +272,7 @@ def performAnalysis(
     
             if method == 'shortest_via_edge':
     
-                splineParams = liga.reposeSpline(splinesLocParams[spline], RTs[i,...])
+                splineParams = liga.reposeSpline(splinesLocParams[spline], RTe[i,...])
                 dummy, ligaPath = liga.ligamentPathBlankevoort1991(ligaPath, splineParams)
     
             ligaLength = np.linalg.norm(np.diff(ligaPath, axis=0), axis=1).sum()
@@ -256,16 +295,10 @@ def performAnalysis(
         plt.legend(loc='upper right', fontsize=7)
         plt.title('Ligament strains (%)') 
 
-    results['paths'].update(ligaPaths)
+    linePaths.update(ligaPaths)
     results['lengths'] = ligaLengths
     results['strains'] = ligaStrains
     
-    
-    
-    linePaths = {}
-    linePaths.update(ligaPaths)
-    
-    
     defL2PProjs = params['defL2PProjs']
     
     L2PProjsList = params['calcL2PProjs']['selected']
@@ -280,13 +313,13 @@ def performAnalysis(
         planeName = defL2PProj['plane']
         segName, normName = planeName.split(';')
         
-        RT = np.array(poses[segName])
+        RT = RTs[segName]
     
         RTi = kine.inv2(RT)
         
+        lineProjPaths[name] = [[]] * N
+        
         for i in range(N):
-            
-            lineProjPaths[name] = [[]] * N
 
             linePath = np.array(linePaths[lineName][i])
     
@@ -294,7 +327,8 @@ def performAnalysis(
             
             for r in range(linePath.shape[0]):
                 points['p%d' % r] = linePath[r,:]
-            pointsInRef = kine.changeMarkersReferenceFrame(points, RTi[i,...])
+
+            pointsInRef = kine.changeMarkersReferenceFrame(points, RTi[i:i+1,...])
     
             if normName == 'nX':
                 idx = 0
@@ -306,31 +340,29 @@ def performAnalysis(
             for p in pointsInRef:
                 pointsInRef[p][0,idx] = 0
     
-            pointsProj = kine.changeMarkersReferenceFrame(pointsInRef, RT[i,...])
+            pointsProj = kine.changeMarkersReferenceFrame(pointsInRef, RT[i:i+1,...])
             pointsProj = np.array([pointsProj[m][0,:] for m in pointsProj])
     
             lineProjPaths[name][i] = pointsProj
         
         
-    results['paths'].update(lineProjPaths)
+    linePaths.update(lineProjPaths)
     
+    defInterlineAngles = params['defInterlineAngles']
     
-    
-    
-    defInterLineAngles = params['defInterLineAngles']
-    
-    interLineAnglesList = params['calcInterLineAnglesList']['selected']
+    interlineAnglesList = params['calcInterlineAngles']['selected']
     
     angles = {}
 
-    for interLineAngleName in interLineAnglesList:
+    for interlineAngleName in interlineAnglesList:
 
-        defInterLineAngle = [a for a in defInterLineAngles if a['name'] == interLineAngleName][0]
-        name = defInterLineAngle['name']
-        lineName1 = defInterLineAngle['line1']
-        lineName2 = defInterLineAngle['line2']
+        defInterlineAngle = [a for a in defInterlineAngles if a['name'] == interlineAngleName][0]
+        name = defInterlineAngle['name']
+        lineName1 = defInterlineAngle['line1']
+        lineName2 = defInterlineAngle['line2']
         
-        angles[name] = [] * N
+#        angles[name] = [None] * N
+        angles[name] = np.nan * np.zeros((N,))
         
         for i in range(N):
 
@@ -344,6 +376,8 @@ def performAnalysis(
             vec2 /= np.linalg.norm(vec2)
     
             angle = np.rad2deg(np.arccos(np.dot(vec1, vec2)))
+            if angle > 90:
+                angle = 180. - angle
     
             angles[name][i] = angle
             
@@ -352,14 +386,10 @@ def performAnalysis(
         plt.legend(loc='upper right', fontsize=7)
         plt.title('Interline angles (deg)')
 
+    results['interline_angles'] = angles
 
-    results["interline_angles"] = angles
+    results['paths'] = linePaths
 
-
-
-
-
-    
     plt.tight_layout()
     
     if not os.path.exists(resultsDir):
