@@ -5,17 +5,19 @@
 """
 
 import vtk
-import fio
+from . import fio
 from vtk.util.numpy_support import vtk_to_numpy as v2n
 import numpy as np
 from scipy import interpolate
 
-
-ew = vtk.vtkFileOutputWindow()
-ew.SetFileName("vtk_errors.log")
-ow = vtk.vtkOutputWindow()
-ow.SendToStdErrOn()
-ow.SetInstance(ew)
+try:
+    ew = vtk.vtkFileOutputWindow()
+    ew.SetFileName("vtk_errors.log")
+    ow = vtk.vtkOutputWindow()
+    ow.SendToStdErrOn()
+    ow.SetInstance(ew)
+except:
+    pass
 
     
     
